@@ -57,10 +57,11 @@ class TikApi(object): # initialize class
         url = self.base_url + "/devreg"
         data = {"key": self._key}
         resp = requests.post(url, data=data).json()
+        
         if resp['status'] == 0:
             return '[*] Invalid API-Key'
         elif resp['status'] == 5:
-            return json.loads(resp)
+            return resp
   
   def xladon(self): # x-ladon
         url = self.base_url + "/xladon"
